@@ -3,6 +3,8 @@
 use 5.024;
 use warnings;
 
+say foo($_) for 0..2;
+
 my %group_of = (
      cats => 'clowder',
      bats => 'colony',
@@ -26,9 +28,21 @@ try {
         }
 
         for (%group_of{@animals}) -> $animal, $group {
+            LEAVE { say "----" }
             FIRST { say "\n(" }
                     say "    '$animal' => '$group',";
             LAST { say ")\n" }
         }
     }
 }
+
+sub foo {
+    my ($x) = @_;
+    LEAVE { say 'leaving foo' }
+    if ($x > 1) {
+        return 'a';
+    }
+    else {
+        return 'b';
+    }
+}
